@@ -32,7 +32,7 @@ class TQTextStream;
 class TQImage;
 class TQPainter;
 
-namespace KIO {
+namespace TDEIO {
     class Job;
 }
 
@@ -199,7 +199,7 @@ public:
 
 class KMPLAYER_NO_EXPORT ImageRuntime : public TQObject,public MediaTypeRuntime {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ImageRuntime (NodePtr e);
     ~ImageRuntime ();
