@@ -34,14 +34,14 @@
 #include <klineedit.h>
 #include <kstatusbar.h>
 
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 #include <kurl.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
 
 #include "kmplayersource.h"
 #include "kmplayerconfig.h"
@@ -83,20 +83,20 @@ static OutputDriver _vds [] = {
 static const int ADRIVER_ARTS_INDEX = 4;
 
 
-KDE_NO_CDTOR_EXPORT Settings::Settings (PartBase * player, KConfig * config)
+KDE_NO_CDTOR_EXPORT Settings::Settings (PartBase * player, TDEConfig * config)
   : pagelist (0L), configdialog (0L), m_config (config), m_player (player) {
     audiodrivers = _ads;
     videodrivers = _vds;
     colors [ColorSetting::playlist_background].title = i18n ("Playlist background");
     colors [ColorSetting::playlist_background].option = "PlaylistBackground";
-    colors [ColorSetting::playlist_background].color = KGlobalSettings::baseColor ();
+    colors [ColorSetting::playlist_background].color = TDEGlobalSettings::baseColor ();
     colors [ColorSetting::playlist_foreground].title = i18n ("Playlist foreground");
     colors [ColorSetting::playlist_foreground].option = "PlaylistForeground";
-    colors [ColorSetting::playlist_foreground].color = KGlobalSettings::textColor();
+    colors [ColorSetting::playlist_foreground].color = TDEGlobalSettings::textColor();
     colors [ColorSetting::console_background].title =i18n("Console background");
     colors [ColorSetting::playlist_active].title = i18n("Playlist active item");
     colors [ColorSetting::playlist_active].option = "PlaylistActive";
-    colors [ColorSetting::playlist_active].color = KGlobalSettings::linkColor();
+    colors [ColorSetting::playlist_active].color = TDEGlobalSettings::linkColor();
     colors [ColorSetting::console_background].option = "ConsoleBackground";
     colors [ColorSetting::console_background].color = TQColor (0, 0, 0);
     colors [ColorSetting::console_foreground].title = i18n ("Console foreground");
@@ -110,17 +110,17 @@ KDE_NO_CDTOR_EXPORT Settings::Settings (PartBase * player, KConfig * config)
     colors [ColorSetting::area_background].color = TQColor (0, 0, 0);
     colors [ColorSetting::infowindow_background].title = i18n ("Info window background");
     colors [ColorSetting::infowindow_background].option ="InfoWindowBackground";
-    colors [ColorSetting::infowindow_background].color = KGlobalSettings::baseColor ();
+    colors [ColorSetting::infowindow_background].color = TDEGlobalSettings::baseColor ();
     colors [ColorSetting::infowindow_foreground].title = i18n ("Info window foreground");
     colors [ColorSetting::infowindow_foreground].option ="InfoWindowForeground";
-    colors [ColorSetting::infowindow_foreground].color = KGlobalSettings::textColor();
+    colors [ColorSetting::infowindow_foreground].color = TDEGlobalSettings::textColor();
     fonts [FontSetting::playlist].title = i18n ("Playlist");
     fonts [FontSetting::playlist].option = "PlaylistFont";
-    fonts [FontSetting::playlist].font = KGlobalSettings::generalFont();
+    fonts [FontSetting::playlist].font = TDEGlobalSettings::generalFont();
     fonts [FontSetting::playlist].font.setItalic (true);
     fonts [FontSetting::infowindow].title = i18n ("Info window");
     fonts [FontSetting::infowindow].option = "InfoWindowFont";
-    fonts [FontSetting::infowindow].font = KGlobalSettings::generalFont();
+    fonts [FontSetting::infowindow].font = TDEGlobalSettings::generalFont();
 }
 
 KDE_NO_CDTOR_EXPORT Settings::~Settings () {
@@ -369,7 +369,7 @@ KDE_NO_EXPORT bool Settings::createDialog () {
             this, TQT_SLOT (okPressed ()));
     connect (configdialog, TQT_SIGNAL (applyClicked ()),
             this, TQT_SLOT (okPressed ()));
-    if (KApplication::kApplication())
+    if (TDEApplication::kApplication())
         connect (configdialog, TQT_SIGNAL (helpClicked ()),
                 this, TQT_SLOT (getHelp ()));
     return true;
@@ -734,7 +734,7 @@ void Settings::okPressed () {
 }
 
 KDE_NO_EXPORT void Settings::getHelp () {
-    KApplication::kApplication()->invokeBrowser ("man:/mplayer");
+    TDEApplication::kApplication()->invokeBrowser ("man:/mplayer");
 }
 
 #include "kmplayerconfig.moc"
