@@ -25,7 +25,7 @@
 #include <tqstringlist.h>
 
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include "kmplayerview.h"
@@ -282,7 +282,7 @@ KDE_NO_EXPORT void KMPlayerMenuButton::enterEvent (TQEvent *) {
 //-----------------------------------------------------------------------------
 
 KDE_NO_CDTOR_EXPORT KMPlayerPopupMenu::KMPlayerPopupMenu (TQWidget * parent)
- : KPopupMenu (parent, "kde_kmplayer_popupmenu") {}
+ : TDEPopupMenu (parent, "kde_kmplayer_popupmenu") {}
 
 KDE_NO_EXPORT void KMPlayerPopupMenu::leaveEvent (TQEvent *) {
     emit mouseLeft ();
@@ -383,11 +383,11 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     m_popupMenu->insertItem (i18n ("&Play with"), m_playerMenu, menu_player);
     m_bookmarkMenu = new KMPlayerPopupMenu (this);
     m_popupMenu->insertItem (i18n("&Bookmarks"), m_bookmarkMenu, menu_bookmark);
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("konsole"), KIcon::Small, 0, true), i18n ("Con&sole"), menu_video);
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("player_playlist"), KIcon::Small, 0, true), i18n ("Play&list"), menu_playlist);
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("empty"), KIcon::Small, 0, true), i18n ("Minimal mode"), menu_minimal);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("konsole"), TDEIcon::Small, 0, true), i18n ("Con&sole"), menu_video);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("player_playlist"), TDEIcon::Small, 0, true), i18n ("Play&list"), menu_playlist);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("application-x-zerosize"), TDEIcon::Small, 0, true), i18n ("Minimal mode"), menu_minimal);
     m_popupMenu->setAccel (TQKeySequence (TQt::Key_M), menu_minimal);
-    m_popupMenu->insertItem (KGlobal::iconLoader()->loadIconSet (TQString ("window_fullscreen"), KIcon::Small, 0, true), i18n ("&Full Screen"), menu_fullscreen);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader()->loadIconSet (TQString ("view-fullscreen"), TDEIcon::Small, 0, true), i18n ("&Full Screen"), menu_fullscreen);
     m_popupMenu->setAccel (TQKeySequence (TQt::Key_F), menu_fullscreen);
     m_zoomMenu = new KMPlayerPopupMenu (this);
     m_zoomMenu->insertItem (i18n ("50%"), menu_zoom50);
@@ -395,14 +395,14 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     m_zoomMenu->insertItem (i18n ("150%"), menu_zoom150);
     m_zoomMenu->insertItem (i18n ("200%"), menu_zoom200);
     m_zoomMenu->insertItem (i18n ("300%"), menu_zoom300);
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("viewmag"), KIcon::Small, 0, false), i18n ("&Zoom"), m_zoomMenu, menu_zoom);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("viewmag"), TDEIcon::Small, 0, false), i18n ("&Zoom"), m_zoomMenu, menu_zoom);
     m_popupMenu->insertSeparator ();
     m_colorMenu = new KMPlayerPopupMenu (this);
     m_languageMenu = new KMPlayerPopupMenu (this);
     m_audioMenu = new KMPlayerPopupMenu (this);
     m_subtitleMenu = new KMPlayerPopupMenu (this);
-    m_languageMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("mime-sound"), KIcon::Small, 0, true), i18n ("&Audio languages"), m_audioMenu);
-    m_languageMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("view_text"), KIcon::Small, 0, true), i18n ("&Subtitles"), m_subtitleMenu);
+    m_languageMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("mime-sound"), TDEIcon::Small, 0, true), i18n ("&Audio languages"), m_audioMenu);
+    m_languageMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("view_text"), TDEIcon::Small, 0, true), i18n ("&Subtitles"), m_subtitleMenu);
     TQLabel * label = new TQLabel (i18n ("Contrast:"), m_colorMenu);
     m_colorMenu->insertItem (label);
     m_contrastSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
@@ -419,9 +419,9 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     m_colorMenu->insertItem (label);
     m_saturationSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
     m_colorMenu->insertItem (m_saturationSlider);
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("colorize"), KIcon::Small, 0, true), i18n ("Co&lors"), m_colorMenu);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("colorize"), TDEIcon::Small, 0, true), i18n ("Co&lors"), m_colorMenu);
     m_popupMenu->insertSeparator ();
-    m_popupMenu->insertItem (KGlobal::iconLoader ()->loadIconSet (TQString ("configure"), KIcon::Small, 0, true), i18n ("&Configure KMPlayer..."), menu_config);
+    m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("configure"), TDEIcon::Small, 0, true), i18n ("&Configure KMPlayer..."), menu_config);
     setAutoControls (true);
     connect (m_buttons [button_config], TQT_SIGNAL (clicked ()),
             this, TQT_SLOT (buttonClicked ()));
