@@ -40,19 +40,19 @@
 #include <tqsocket.h>
 #include <tqeventloop.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <klineedit.h>
 #include <kurlrequester.h>
 #include <kcombobox.h>
 #include <kstatusbar.h>
 #include <kprocess.h>
-#include <kconfig.h>
-#include <kaction.h>
+#include <tdeconfig.h>
+#include <tdeaction.h>
 #include <kiconloader.h>
-#include <klistview.h>
-#include <kdeversion.h>
+#include <tdelistview.h>
+#include <tdeversion.h>
 #if KDE_IS_VERSION(3, 1, 90)
 #include <kinputdialog.h>
 #endif
@@ -80,7 +80,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPrefSourcePageVDR::KMPlayerPrefSourcePageVDR (TQWidg
     //KURLRequester * v4ldevice;
     TQVBoxLayout *layout = new TQVBoxLayout (this, 5, 2);
     TQGridLayout *gridlayout = new TQGridLayout (1, 2);
-    xv_port = new KListView (this);
+    xv_port = new TDEListView (this);
     xv_port->addColumn (TQString());
     xv_port->header()->hide ();
     xv_port->setTreeStepSize (15);
@@ -140,7 +140,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerVDRSource::KMPlayerVDRSource (KMPlayerApp * app)
    finish_timer (0),
    tcp_port (0),
    m_stored_volume (0) {
-    memset (m_actions, 0, sizeof (KAction *) * int (act_last));
+    memset (m_actions, 0, sizeof (TDEAction *) * int (act_last));
     m_player->settings ()->addPage (this);
     connect (m_socket, TQT_SIGNAL (connectionClosed()), this, TQT_SLOT(disconnected()));
     connect (m_socket, TQT_SIGNAL (connected ()), this, TQT_SLOT (connected ()));
@@ -229,19 +229,19 @@ KDE_NO_EXPORT void KMPlayerVDRSource::processStarted () {
 }
 
 #define DEF_ACT(i,text,pix,scut,slot,name) \
-    m_actions [i] = new KAction (text, TQString (pix), KShortcut (scut), this, slot, m_app->actionCollection (), name); \
-    m_fullscreen_actions [i] = new KAction (text, KShortcut (scut), this, slot, m_app->view ()->viewArea ()->actionCollection (), name)
+    m_actions [i] = new TDEAction (text, TQString (pix), TDEShortcut (scut), this, slot, m_app->actionCollection (), name); \
+    m_fullscreen_actions [i] = new TDEAction (text, TDEShortcut (scut), this, slot, m_app->view ()->viewArea ()->actionCollection (), name)
 
 KDE_NO_EXPORT void KMPlayerVDRSource::connected () {
     queueCommand (cmd_list_channels);
     queueCommand (cmd_volume_query);
     killTimer (channel_timer);
     channel_timer = startTimer (3000);
-    KAction * action = m_app->actionCollection ()->action ("vdr_connect");
+    TDEAction * action = m_app->actionCollection ()->action ("vdr_connect");
     action->setIcon (TQString ("connect_no"));
     action->setText (i18n ("Dis&connect"));
-    DEF_ACT (act_up, i18n ("VDR Key Up"), "up", , TQT_SLOT (keyUp ()), "vdr_key_up");
-    DEF_ACT (act_down, i18n ("VDR Key Down"), "down", , TQT_SLOT (keyDown ()), "vdr_key_down");
+    DEF_ACT (act_up, i18n ("VDR Key Up"), "go-up", , TQT_SLOT (keyUp ()), "vdr_key_up");
+    DEF_ACT (act_down, i18n ("VDR Key Down"), "go-down", , TQT_SLOT (keyDown ()), "vdr_key_down");
     DEF_ACT (act_back, i18n ("VDR Key Back"), "back", , TQT_SLOT (keyBack ()), "vdr_key_back");
     DEF_ACT (act_ok, i18n ("VDR Key Ok"), "ok", , TQT_SLOT (keyOk ()), "vdr_key_ok");
     DEF_ACT (act_setup, i18n ("VDR Key Setup"), "configure", , TQT_SLOT (keySetup ()), "vdr_key_setup");
@@ -251,9 +251,7 @@ KDE_NO_EXPORT void KMPlayerVDRSource::connected () {
     DEF_ACT (act_green, i18n ("VDR Key Green"), "green", , TQT_SLOT (keyGreen ()), "vdr_key_green");
     DEF_ACT (act_yellow, i18n ("VDR Key Yellow"), "yellow", , TQT_SLOT (keyYellow ()), "vdr_key_yellow");
     DEF_ACT (act_blue, i18n ("VDR Key Blue"), "blue", , TQT_SLOT (keyBlue ()), "vdr_key_blue");
-#if KDE_IS_VERSION(3, 1, 90)
-    DEF_ACT (act_custom, "VDR Custom Command", "exec", , TQT_SLOT (customCmd ()), "vdr_key_custom");
-#endif
+    DEF_ACT (act_custom, "VDR Custom Command", "application-x-executable", , TQT_SLOT (customCmd ()), "vdr_key_custom");
     m_app->initMenu (); // update menu and toolbar
     DEF_ACT (act_0, i18n ("VDR Key 0"), "0", TQt::Key_0, TQT_SLOT (key0 ()), "vdr_key_0");
     DEF_ACT (act_1, i18n ("VDR Key 1"), "1", TQt::Key_1, TQT_SLOT (key1 ()), "vdr_key_1");
@@ -284,7 +282,7 @@ KDE_NO_EXPORT void KMPlayerVDRSource::disconnected () {
     if (channel_timer && m_player->source () == this)
         m_player->process ()->quit ();
     deleteCommands ();
-    KAction * action = m_app->actionCollection ()->action ("vdr_connect");
+    TDEAction * action = m_app->actionCollection ()->action ("vdr_connect");
     action->setIcon (TQString ("connect_established"));
     action->setText (i18n ("&Connect"));
     m_app->guiFactory ()->removeClient (m_app);// crash w/ m_actions[i]->unplugAll (); in for loop below
@@ -635,7 +633,7 @@ KDE_NO_EXPORT void KMPlayerVDRSource::keyBlue () {
     queueCommand ("HITK BLUE\n");
 }
 
-KDE_NO_EXPORT void KMPlayerVDRSource::write (KConfig * m_config) {
+KDE_NO_EXPORT void KMPlayerVDRSource::write (TDEConfig * m_config) {
     m_config->setGroup (strVDR);
     m_config->writeEntry (strVDRPort, tcp_port);
     m_config->writeEntry (strXVPort, m_xvport);
@@ -643,7 +641,7 @@ KDE_NO_EXPORT void KMPlayerVDRSource::write (KConfig * m_config) {
     m_config->writeEntry (strXVScale, scale);
 }
 
-KDE_NO_EXPORT void KMPlayerVDRSource::read (KConfig * m_config) {
+KDE_NO_EXPORT void KMPlayerVDRSource::read (TDEConfig * m_config) {
     m_config->setGroup (strVDR);
     tcp_port = m_config->readNumEntry (strVDRPort, 2001);
     m_xvport = m_config->readNumEntry (strXVPort, 0);
@@ -724,7 +722,7 @@ KDE_NO_EXPORT void KMPlayerVDRSource::configReceived () {
 
 KDE_NO_EXPORT void KMPlayerVDRSource::prefLocation (TQString & item, TQString & icon, TQString & tab) {
     item = i18n ("Source");
-    icon = TQString ("source");
+    icon = TQString ("text-x-src");
     tab = i18n ("VDR");
 }
 
@@ -773,7 +771,7 @@ KDE_NO_EXPORT bool XVideo::ready (KMPlayer::Viewer * v) {
     }
     fprintf (stderr, "%s\n", cmd.latin1 ());
     *m_process << cmd;
-    m_process->start (KProcess::NotifyOnExit, KProcess::All);
+    m_process->start (TDEProcess::NotifyOnExit, TDEProcess::All);
     return m_process->isRunning ();
 }
 
