@@ -43,15 +43,15 @@
 #include <kiconloader.h>
 #include <kstatusbar.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kactioncollection.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeactioncollection.h>
 #include <kstdaction.h>
-#include <kshortcut.h>
+#include <tdeshortcut.h>
 #include <kurldrag.h>
 #include <kfinddialog.h>
 #include <dcopclient.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kstaticdeleter.h>
 
 #include "kmplayerview.h"
@@ -171,20 +171,20 @@ KDE_NO_EXPORT void View::dragEnterEvent (TQDragEnterEvent* dee) {
         dee->accept ();
 }
 
-KDE_NO_EXPORT void View::init (KActionCollection * action_collection) {
+KDE_NO_EXPORT void View::init (TDEActionCollection * action_collection) {
     setBackgroundMode(TQt::NoBackground); // prevents flashing
     //m_dockarea->setEraseColor (TQColor (0, 0, 0));
     TQPalette pal (TQColor (64, 64,64), TQColor (32, 32, 32));
     TQVBoxLayout * viewbox = new TQVBoxLayout (this, 0, 0);
     m_dockarea = new KDockArea (this, "kde_kmplayer_dock_area");
-    m_dock_video = new KDockWidget (m_dockarea->manager (), 0, KGlobal::iconLoader ()->loadIcon (TQString ("kmplayer"), KIcon::Small), m_dockarea);
+    m_dock_video = new KDockWidget (m_dockarea->manager (), 0, TDEGlobal::iconLoader ()->loadIcon (TQString ("kmplayer"), TDEIcon::Small), m_dockarea);
     m_dock_video->setEraseColor (TQColor (0, 0, 255));
     m_dock_video->setDockSite (KDockWidget::DockLeft | KDockWidget::DockBottom | KDockWidget::DockRight | KDockWidget::DockTop);
     m_dock_video->setEnableDocking(KDockWidget::DockNone);
     m_view_area = new ViewArea (m_dock_video, this);
     m_dock_video->setWidget (m_view_area);
     m_dockarea->setMainDockWidget (m_dock_video);
-    m_dock_playlist = m_dockarea->createDockWidget (i18n ("Play List"), KGlobal::iconLoader ()->loadIcon (TQString ("player_playlist"), KIcon::Small));
+    m_dock_playlist = m_dockarea->createDockWidget (i18n ("Play List"), TDEGlobal::iconLoader ()->loadIcon (TQString ("player_playlist"), TDEIcon::Small));
     m_playlist = new PlayListView (m_dock_playlist, this, action_collection);
     m_dock_playlist->setWidget (m_playlist);
     viewbox->addWidget (m_dockarea);
@@ -204,13 +204,13 @@ KDE_NO_EXPORT void View::init (KActionCollection * action_collection) {
 
     m_multiedit = new TextEdit (m_widgetstack, this);
     m_multiedit->setTextFormat (TQt::PlainText);
-    TQFont fnt = KGlobalSettings::fixedFont ();
+    TQFont fnt = TDEGlobalSettings::fixedFont ();
     m_multiedit->setFont (fnt);
     m_widgettypes[WT_Console] = m_multiedit;
 
     m_widgettypes[WT_Picture] = new KMPlayerPictureWidget (m_widgetstack, this);
 
-    m_dock_infopanel = m_dockarea->createDockWidget ("infopanel", KGlobal::iconLoader ()->loadIcon (TQString ("info"), KIcon::Small));
+    m_dock_infopanel = m_dockarea->createDockWidget ("infopanel", TDEGlobal::iconLoader ()->loadIcon (TQString ("application-vnd.tde.info"), TDEIcon::Small));
     m_infopanel = new InfoWindow (m_dock_infopanel, this);
     m_dock_infopanel->setWidget (m_infopanel);
 
@@ -394,9 +394,9 @@ void View::toggleVideoConsoleWindow () {
     WidgetType wt = WT_Console;
     if (m_widgetstack->visibleWidget () == m_widgettypes[WT_Console]) {
         wt = WT_Video;
-        m_control_panel->popupMenu ()->changeItem (ControlPanel::menu_video, KGlobal::iconLoader ()->loadIconSet (TQString ("konsole"), KIcon::Small, 0, true), i18n ("Con&sole"));
+        m_control_panel->popupMenu ()->changeItem (ControlPanel::menu_video, TDEGlobal::iconLoader ()->loadIconSet (TQString ("konsole"), TDEIcon::Small, 0, true), i18n ("Con&sole"));
     } else
-        m_control_panel->popupMenu ()->changeItem (ControlPanel::menu_video, KGlobal::iconLoader ()->loadIconSet (TQString ("video"), KIcon::Small, 0, true), i18n ("V&ideo"));
+        m_control_panel->popupMenu ()->changeItem (ControlPanel::menu_video, TDEGlobal::iconLoader ()->loadIconSet (TQString ("video-x-generic"), TDEIcon::Small, 0, true), i18n ("V&ideo"));
     showWidget (wt);
     emit windowVideoConsoleToggled (int (wt));
 }
@@ -577,7 +577,7 @@ KDE_NO_EXPORT void View::playingStop () {
     m_playing = false;
     WId w = m_viewer->embeddedWinId ();
     if (w)
-        XClearWindow (qt_xdisplay(), w);
+        XClearWindow (tqt_xdisplay(), w);
     m_view_area->resizeEvent (0L);
 }
 
@@ -674,12 +674,12 @@ KDE_NO_CDTOR_EXPORT Viewer::Viewer (TQWidget *parent, View * view)
   : QXEmbed (parent), m_plain_window (0), m_bgcolor (0), m_aspect (0.0),
     m_view (view) {
     /*XWindowAttributes xwa;
-    XGetWindowAttributes (qt_xdisplay(), winId (), &xwa);
+    XGetWindowAttributes (tqt_xdisplay(), winId (), &xwa);
     XSetWindowAttributes xswa;
     xswa.background_pixel = 0;
     xswa.border_pixel = 0;
     xswa.colormap = xwa.colormap;
-    create (XCreateWindow (qt_xdisplay (), parent->winId (), 0, 0, 10, 10, 0, 
+    create (XCreateWindow (tqt_xdisplay (), parent->winId (), 0, 0, 10, 10, 0, 
                            x11Depth (), InputOutput, (Visual*)x11Visual (),
                            CWBackPixel | CWBorderPixel | CWColormap, &xswa));*/
     setAcceptDrops (true);
@@ -696,22 +696,22 @@ KDE_NO_EXPORT void Viewer::changeProtocol (QXEmbed::Protocol p) {
         if (p == QXEmbed::XPLAIN) {
             setProtocol (p);
             if (!m_plain_window) {
-                int scr = DefaultScreen (qt_xdisplay ());
+                int scr = DefaultScreen (tqt_xdisplay ());
                 m_plain_window = XCreateSimpleWindow (
-                        qt_xdisplay(),
+                        tqt_xdisplay(),
                         m_view->winId (),
                         0, 0, width(), height(),
                         1,
-                        BlackPixel (qt_xdisplay(), scr),
-                        BlackPixel (qt_xdisplay(), scr));
+                        BlackPixel (tqt_xdisplay(), scr),
+                        BlackPixel (tqt_xdisplay(), scr));
                 embed (m_plain_window);
             }
-            XClearWindow (qt_xdisplay(), m_plain_window);
+            XClearWindow (tqt_xdisplay(), m_plain_window);
         } else {
             if (m_plain_window) {
-                XDestroyWindow (qt_xdisplay(), m_plain_window);
+                XDestroyWindow (tqt_xdisplay(), m_plain_window);
                 m_plain_window = 0;
-                XSync (qt_xdisplay (), false);
+                XSync (tqt_xdisplay (), false);
             }
             //setProtocol (p);
             setProtocol (QXEmbed::XPLAIN);
@@ -722,7 +722,7 @@ KDE_NO_EXPORT void Viewer::changeProtocol (QXEmbed::Protocol p) {
 KDE_NO_EXPORT void Viewer::windowChanged (WId w) {
     kdDebug () << "windowChanged " << (int)w << endl;
     if (w /*&& m_plain_window*/)
-        XSelectInput (qt_xdisplay (), w, 
+        XSelectInput (tqt_xdisplay (), w, 
                 //KeyPressMask | KeyReleaseMask |
                 KeyPressMask |
                 //EnterWindowMask | LeaveWindowMask |
@@ -766,12 +766,12 @@ void Viewer::sendKeyEvent (int key) {
         KeySym keysym = XStringToKeysym (buf);
         XKeyEvent event = {
             XKeyPress, 0, true,
-            qt_xdisplay (), w, qt_xrootwin(), w,
+            tqt_xdisplay (), w, tqt_xrootwin(), w,
             /*time*/ 0, 0, 0, 0, 0,
-            0, XKeysymToKeycode (qt_xdisplay (), keysym), true
+            0, XKeysymToKeycode (tqt_xdisplay (), keysym), true
         };
-        XSendEvent (qt_xdisplay(), w, false, KeyPressMask, (XEvent *) &event);
-        XFlush (qt_xdisplay ());
+        XSendEvent (tqt_xdisplay(), w, false, KeyPressMask, (XEvent *) &event);
+        XFlush (tqt_xdisplay ());
     }
 }
 
@@ -780,12 +780,12 @@ KDE_NO_EXPORT void Viewer::sendConfigureEvent () {
     if (w) {
         XConfigureEvent c = {
             ConfigureNotify, 0UL, True,
-            qt_xdisplay (), w, winId (),
+            tqt_xdisplay (), w, winId (),
             x (), y (), width (), height (),
             0, None, False
         };
-        XSendEvent(qt_xdisplay(),c.event,true,StructureNotifyMask,(XEvent*)&c);
-        XFlush (qt_xdisplay ());
+        XSendEvent(tqt_xdisplay(),c.event,true,StructureNotifyMask,(XEvent*)&c);
+        XFlush (tqt_xdisplay ());
     }
 }
 
@@ -808,8 +808,8 @@ KDE_NO_EXPORT void Viewer::setCurrentBackgroundColor (const TQColor & c) {
     setPaletteBackgroundColor (c);
     WId w = embeddedWinId ();
     if (w) {
-        XSetWindowBackground (qt_xdisplay (), w, c.rgb ());
-        XFlush (qt_xdisplay ());
+        XSetWindowBackground (tqt_xdisplay (), w, c.rgb ());
+        XFlush (tqt_xdisplay ());
     }
 }
 
