@@ -29,12 +29,12 @@
 #include <tqimage.h>
 #include <tqmap.h>
 
-#include <kactioncollection.h>
+#include <tdeactioncollection.h>
 #include <kstaticdeleter.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
-#include <kshortcut.h>
-#include <klocale.h>
+#include <tdeshortcut.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include "kmplayerview.h"
@@ -222,16 +222,16 @@ KDE_NO_EXPORT void ViewSurface::video () {
 #ifdef HAVE_CAIRO
 
 static cairo_surface_t * cairoCreateSurface (Window id, int w, int h) {
-    Display * display = qt_xdisplay ();
+    Display * display = tqt_xdisplay ();
     return cairo_xlib_surface_create (display, id,
             DefaultVisual (display, DefaultScreen (display)), w, h);
     /*return cairo_xlib_surface_create_with_xrender_format (
-            qt_xdisplay (),
+            tqt_xdisplay (),
             id,
-            DefaultScreenOfDisplay (qt_xdisplay ()),
-            XRenderFindVisualFormat (qt_xdisplay (),
-                DefaultVisual (qt_xdisplay (),
-                    DefaultScreen (qt_xdisplay ()))),
+            DefaultScreenOfDisplay (tqt_xdisplay ()),
+            XRenderFindVisualFormat (tqt_xdisplay (),
+                DefaultVisual (tqt_xdisplay (),
+                    DefaultScreen (tqt_xdisplay ()))),
             w, h);*/
 }
 
@@ -550,7 +550,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::Transition *trans) {
             case SMIL::Transition::SubHorizontal:
                 phi = 0;
                 break;
-            default: //Qt::Vertical
+            default: // Vertical
                 phi = -M_PI / 2;
                 break;
         }
@@ -1342,7 +1342,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (TQWidget * parent, View * view)
  : TQWidget (parent, "kde_kmplayer_viewarea", WResizeNoErase | WRepaintNoErase),
    m_parent (parent),
    m_view (view),
-   m_collection (new KActionCollection (this)),
+   m_collection (new TDEActionCollection (this)),
    surface (new ViewSurface (this)),
    m_mouse_invisible_timer (0),
    m_repaint_timer (0),
@@ -1353,7 +1353,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (TQWidget * parent, View * view)
    m_minimal (false) {
     setEraseColor (TQColor (0, 0, 0));
     setAcceptDrops (true);
-    new KAction (i18n ("Fullscreen"), KShortcut (TQt::Key_F), TQT_TQOBJECT(this), TQT_SLOT (accelActivated ()), m_collection, "view_fullscreen_toggle");
+    new TDEAction (i18n ("Fullscreen"), TDEShortcut (TQt::Key_F), TQT_TQOBJECT(this), TQT_SLOT (accelActivated ()), m_collection, "view_fullscreen_toggle");
     setMouseTracking (true);
     if (!image_data_map)
         imageCacheDeleter.setObject (image_data_map, new ImageDataMap);
@@ -1429,7 +1429,7 @@ void ViewArea::minimalMode () {
 }
 
 KDE_NO_EXPORT void ViewArea::accelActivated () {
-    m_view->controlPanel()->popupMenu ()->activateItemAt (m_view->controlPanel()->popupMenu ()->indexOf (ControlPanel::menu_fullscreen)); 
+    m_view->controlPanel()->popupMenu ()->activateItemAt (m_view->controlPanel()->popupMenu ()->indexOf (ControlPanel::menu_fullscreen));
 }
 
 KDE_NO_EXPORT void ViewArea::mousePressEvent (TQMouseEvent * e) {
@@ -1487,7 +1487,7 @@ KDE_NO_EXPORT void ViewArea::syncVisual (const IRect & rect) {
         killTimer (m_repaint_timer);
         m_repaint_timer = 0;
     }
-    //XFlush (qt_xdisplay ());
+    //XFlush (tqt_xdisplay ());
 }
 
 KDE_NO_EXPORT void ViewArea::paintEvent (TQPaintEvent * pe) {
